package
Version:
v1.0.1
Opens a new window with list of versions in this module.
Published: Dec 14, 2018
License: MIT
Opens a new window with license information.
Imports: 10
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
InitSecretFile ... to generate
func LoadSecretFile() error
LoadSecretFile ...
type Args struct {
UID string `json:"uid"`
ResDesc string `json:"res_desc"`
Action string `json:"action"`
}
Args ...
Auth for rpc calling
IsPermitted check the permitted or not
Source Files
¶
Click to show internal directories.
Click to hide internal directories.